@@ -22,7 +22,7 @@ Copyright 2003-2007 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: data.c 1565 2009-08-03 14:48:56Z beerli $
+$Id: data.c 1593 2009-12-06 22:42:27Z beerli $
  
 -------------------------------------------------------*/
 /*! \file data.c
@@ -240,6 +240,22 @@ void shuffle_data(data_fmt *data, option_fmt *options)
     }
 }
 
+
+long max_shuffled_individuals(option_fmt *options, data_fmt *data, long pop, long locus)
+{
+  long top;
+  if(options->randomsubset>0 && options->randomsubset <  data->numind[pop][locus])
+    {	
+      top = options->randomsubset;
+    }
+  else
+    {
+      top = data->numind[pop][locus];
+    }
+  return top;
+}
+
+
 //---------------------------------------------------------------
 // ..number_pop.number_loci.<delimiter>.<title [no numbers to start]
 // locu_specification {sNumber_of_sites}{n{number of sites}{m1}{a1}
@@ -454,6 +470,9 @@ init_data_structure1 (data_fmt ** data, option_fmt * options)
         (*data)->seq[0]->links = (boolean *) mycalloc (loci, sizeof (boolean));
         (*data)->position = (long *) mycalloc (loci, sizeof (long));
 	(*data)->datatype = (long *) mycalloc(loci, sizeof(long));
+	(*data)->numdatatypealloc = loci;
+	(*data)->numsublocialloc = loci;
+	(*data)->subloci = mycalloc(loci,sizeof(long));
     }
     else
     {
@@ -681,9 +700,14 @@ find_delimiter (char *title, char *dlm)
     }
 }
 
-void set_datatype(char input, long locus, char *locitypes)
+void set_datatype(char input, long locus, char ** locitypes, long *alloc)
 {
-  locitypes[locus] = input;
+  if(locus >= *alloc)
+    {
+      *alloc += SUBLOCICHUNKS;
+      *locitypes = myrealloc(*locitypes, sizeof(char) * (*alloc));
+    }
+  (*locitypes)[locus] = input;
 }
 
 //==================================================================
@@ -728,6 +752,11 @@ read_sites (data_fmt * data, world_fmt *world)
 	    // still unclear how to deal with haplotype versus diplotype information
 	    data->oneliner=TRUE;
 	    linked=TRUE;
+	    if(z>=data->numsublocialloc)
+	      {
+		data->numsublocialloc += SUBLOCICHUNKS;
+		data->subloci = (long *) myrealloc(data->subloci, data->numsublocialloc * sizeof(long));
+	      }
 	    data->subloci[z] += 1; //we opened a ( and therefore start a linkage group
 	    if(input[1]!='\0' && isalpha(input[1]))
 	      {
@@ -744,19 +773,19 @@ read_sites (data_fmt * data, world_fmt *world)
 
 		    if(val==0)
 		      {
-			set_datatype((input[0]=='(' ? input[1] : input[0]),locus, &world->mutationmodels[zz].datatype);
+                        set_datatype((input[0]=='(' ? input[1] : input[0]),locus, &data->locitypes, &data->numlocitypesalloc);
 			zz++;
 		      }
 		    else
 		      {
 			// no datatype specified in the model therewe assume there is a unique data type specified in the parmfile or menu
-			set_datatype(data->datatype[0],locus, &world->mutationmodels[zz].datatype);
+                        set_datatype(data->datatype[0],locus, &data->locitypes, &data->numlocitypesalloc);
 		      }
 		  }
 		else
 		  {
 		    // no datatype specified in the model therefore we assume there is a unique data type specified in the parmfile or menu
-		    set_datatype(data->datatype[0],locus, &world->mutationmodels[zz].datatype);
+                    set_datatype(data->datatype[0],locus, &data->locitypes, &data->numlocitypesalloc);
 		  }
 	      }
 	    else
@@ -880,18 +909,24 @@ read_old_sites (data_fmt * data)
 		    else
 		      val=strchr("bmsnuh", input[1]);
 
-		    if(val==0)
-		      {
-			set_datatype((input[0]=='(' ? input[1] : input[0]),locus, data->locitypes);
-		      }
-		    else
-		      {
-			set_datatype(data->datatype[0],locus, data->locitypes);
-		      }
+
+                    if(val==0)
+                      {
+                        set_datatype((input[0]=='(' ? input[1] : input[0]),locus, &data->locitypes, &data->numlocitypesalloc);
+                        //zz++;
+                      }
+                    else
+                      {
+                        // no datatype specified in the model therefore we assume there is a                                                  
+                        // unique data type specified in the parmfile or menu                                                                 
+                        set_datatype(data->datatype[0],locus, &data->locitypes, &data->numlocitypesalloc);
+                      }
 		  }
 		else
 		  {
-		    set_datatype(data->datatype[0],locus, data->locitypes);
+                    // no datatype specified in the model therefore we assume there is a unique data type specified in the parmfile or menu   
+                    set_datatype(data->datatype[0],locus, &data->locitypes, &data->numlocitypesalloc);
+
 		  }
 	      }
 	    else
@@ -991,22 +1026,22 @@ read_popheader (FILE * infile, data_fmt * data, option_fmt * options, long pop,
     // allows that sequence data can have different numbers of individuals for different loci
     // data syntax changes: #ind1 #ind2 #IND3 .... pop_name
     havepopname=FALSE;
-    if(data->loci>1)
+    // with multiple loci we need to separate the nubers of individuals per locus
+    // from the population title, and also take care in case the number of 
+    // individuals is not specified for all loci.
+    if(data->loci>1) 
     {
         read_word(data->infile, input);
 	while(input[0]=='#')
 	  {
-	    FGETS(input,LINESIZE,data->infile);
-	    read_word(data->infile, input);
+	    FGETS(input,LINESIZE,data->infile);//read rest of line and discard
+	    read_word(data->infile, input);    //read first word on next line
 	  }
-        data->numind[pop][0] = atol(input);
-	//if(options->randomsubset > 0 && options->randomsubset < data->numind[pop][0])
-	//  data->numalleles[pop][0] = options->randomsubset * genomes;
-	//else
-	  data->numalleles[pop][0] = data->numind[pop][0] * genomes;
+        data->numind[pop][0] = atol(input);//set first numind value, this must be always present
+	data->numalleles[pop][0] = data->numind[pop][0] * genomes;
         for(locus=1; locus < data->loci; locus++)
         {
-            read_word(infile, input);
+	  read_word(infile, input);// if we encounter a # we treat the rest of the line as comment
 	    while(input[0]=='#')
 	      {
 		FGETS(input,LINESIZE,data->infile);
@@ -1015,13 +1050,11 @@ read_popheader (FILE * infile, data_fmt * data, option_fmt * options, long pop,
             if(isdigit(input[0]) && havepopname == FALSE )
 	      {
                 data->numind[pop][locus] = atol(input);
-		//if(options->randomsubset > 0 && options->randomsubset < data->numind[pop][locus])
-		//  data->numalleles[pop][locus] = options->randomsubset * genomes;
-		//else
-		  data->numalleles[pop][locus] = data->numind[pop][locus] * genomes;
+		data->numalleles[pop][locus] = data->numind[pop][locus] * genomes;
 	      }
             else
 	      {
+		// encountered a letter and assume this is the population name
                 unread_word(infile, input);
                 FGETS(input,LINESIZE,infile);
                 havepopname=TRUE;
@@ -1031,7 +1064,7 @@ read_popheader (FILE * infile, data_fmt * data, option_fmt * options, long pop,
 		    minlength = MIN(minlength,80);
 		    strncpy(data->popnames[pop],input,minlength);
 		  }
-                break;
+                break;//this leaves the numind empty of not specified, the must be filled in later
 	      }
         }
         if(!havepopname)
@@ -1039,41 +1072,31 @@ read_popheader (FILE * infile, data_fmt * data, option_fmt * options, long pop,
             read_word(infile, input);
 	    if(input!=NULL)
 	      {
+                unread_word(infile, input);
+                FGETS(input,LINESIZE,infile);
 		minlength = strlen(input);
 		minlength = MIN(minlength,80);
 		strncpy(data->popnames[pop],input,minlength);
 	      }
-	    //            strncpy(data->popnames[pop],input,MIN(strlen(input),80));
 	  }
 	
         // fills numind for additional locus in case the numind was not specified
         for(lo=locus; lo < data->loci; lo++)
 	  {
             data->numind[pop][lo] = data->numind[pop][locus-1];
-	    //if(options->randomsubset > 0 && options->randomsubset < data->numind[pop][lo])
-	    //  data->numalleles[pop][lo] = options->randomsubset * genomes;
-	    //else
-	      data->numalleles[pop][lo] = data->numind[pop][lo] * genomes;
+	    data->numalleles[pop][lo] = data->numind[pop][lo] * genomes;
 	  }
     }
     else
       {
         // only one locus so we can use old scheme [see below]
         FGETS(input,LINESIZE,infile);
-	//i=0;
-	//while(isspace(input[i] && input[i]!='\0'))
-	//      i++;
-	while(input[0]=='#')// || input[0] == '\n' | input[0] == '\0')
+	while(input[0]=='#')
 	  {
 	    FGETS(input,LINESIZE,data->infile);
 	  }
-
-        sscanf (input, "%ld%[^\n]", &(data->numind[pop][0]),
-                data->popnames[pop]);
-	//if(options->randomsubset > 0 && options->randomsubset < data->numind[pop][0])
-	//  data->numalleles[pop][0] = options->randomsubset * genomes;
-	//else
-	  data->numalleles[pop][0] = data->numind[pop][0] * genomes;
+        sscanf (input, "%ld%[^\n]", &(data->numind[pop][0]), data->popnames[pop]);
+	data->numalleles[pop][0] = data->numind[pop][0] * genomes;
       }
     
     translate (data->popnames[pop], ' ', '_');
