@@ -7,7 +7,7 @@
  
  moved out from world.c                                                                                                               
  Peter Beerli 2000, Seattle
- beerli@scs.fsu.edu
+ beerli@fsu.edu
  
  Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
 Copyright 2003-2004 Peter Beerli, Tallahassee FL
@@ -16,7 +16,7 @@ Copyright 2003-2004 Peter Beerli, Tallahassee FL
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-$Id: lrt.c 904 2007-09-11 13:23:02Z beerli $
+$Id: lrt.c 1323 2008-07-25 19:13:48Z beerli $
  
 -------------------------------------------------------*/
 /* \file lrt.c 
