@@ -26,7 +26,7 @@
 *   works and am not responsible for any damage you may cause or have.
 *
 */
-/* $Id: main.c 1593 2009-12-06 22:42:27Z beerli $*/
+/* $Id: main.c 1597 2010-01-20 14:46:30Z beerli $*/
 
 #include "migration.h"
 #include "sighandler.h"
@@ -2555,7 +2555,7 @@ void print_bayesfactor(FILE *file, world_fmt **universe, option_fmt * options)
 	      printf("%f\n",scaling_factor);
 	    }
 	  scaling_factor = log(scaling_factor) + EARTH->bayes->maxmaxvala;
-	  printf("%f\n",scaling_factor);
+	  // printf("%f\n",scaling_factor);
 	  bfsum += scaling_factor;
 	  bfsum2 += scaling_factor;
 #endif
@@ -2592,7 +2592,7 @@ void print_bayesfactor(FILE *file, world_fmt **universe, option_fmt * options)
       if(EARTH->loci>1)
 	{
 	  fprintf(file,"---------------------------------------------------------------------------------------\n");
-	  fprintf(file,"  All            ------                           ------            %12.2f\n", hsum); 
+	  fprintf(file,"      All           ------                           ------            %12.2f\n", hsum); 
 #ifdef PRETTY
 	  if(file==EARTH->outfile)
 	    pdf_bayes_factor_rawscores_harmo(-1, hsum);
@@ -2609,7 +2609,7 @@ void print_bayesfactor(FILE *file, world_fmt **universe, option_fmt * options)
   if(file==EARTH->outfile)
     pdf_bayes_factor(EARTH, bfsum, bfsum2, hsum, asum, maxreplicate);
 #endif
-} 
+}
 
 ///
 /// integrates over a Bezier curve between two points
