@@ -22,7 +22,7 @@ Copyright 2003-2007 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: random.c 1444 2008-10-18 14:04:48Z beerli $
+$Id: random.c 1553 2009-06-09 15:29:10Z beerli $
 -------------------------------------------------------*/
 /* \file random.c */
 #include "sighandler.h"
@@ -634,7 +634,15 @@ randum (void)
 /* Non thread-safe random number generator (faster) */
 {
 #ifdef MERSENNE_TWISTER
-    return genrand_res53();
+#ifdef MESS
+    MYREAL val = genrand_res53();
+    fprintf(stdout,"%i> R:%f\n",myID,val);
+    return val;
+#else
+    MYREAL r = genrand_res53();
+    //fprintf(stdout,"%f\n",r);
+    return r;
+#endif
 #else
 MYREAL value;
 newseed[0] = 1549 * seed[0];
