@@ -15,7 +15,7 @@
 Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
 Copyright 2003-2009 Peter Beerli, Tallahassee FL
  
-$Id: tree.h 1549 2009-06-04 20:06:57Z beerli $
+$Id: tree.h 1569 2009-08-28 00:38:47Z beerli $
 -------------------------------------------------------*/
 #include "migration.h"
 void buildtree (world_fmt * world, option_fmt * options, data_fmt * data, long locus);
@@ -24,6 +24,8 @@ void allocate_lineages (timelist_fmt **timevector,  long offset, long numpop);
 void allocate_tip (world_fmt * world, option_fmt * options, node ** p, long pop, long locus, long a, long ind, char *tipname);
 void fix_times (world_fmt * world, option_fmt * options);
 void first_smooth (world_fmt * world, long locus);
+void smooth (const node * root, node * p, world_fmt * world, const long locus);
+void set_all_dirty (const node * root, node * p, world_fmt * world, const long locus);
 void set_dirty (node * p);
 void construct_tymelist (world_fmt * world, timelist_fmt * timevector);
 //void timeslices (timelist_fmt ** timevector);
